summaryrefslogtreecommitdiff
path: root/include/pwm.h
diff options
context:
space:
mode:
Diffstat (limited to 'include/pwm.h')
-rw-r--r--include/pwm.h17
1 files changed, 10 insertions, 7 deletions
diff --git a/include/pwm.h b/include/pwm.h
index 022a21399b..26e5fa4686 100644
--- a/include/pwm.h
+++ b/include/pwm.h
@@ -10,29 +10,32 @@
#include "common.h"
-/* Initializes the module. */
+/* Initialize the module. */
int pwm_init(void);
/* Enables/disables the fan. This should be called by whatever function
* enables the power supply to the fan. */
int pwm_enable_fan(int enable);
-/* Gets the current fan RPM. */
+/* Get the current fan RPM. */
int pwm_get_fan_rpm(void);
/* Get the target fan RPM. */
int pwm_get_fan_target_rpm(void);
-/* Sets the target fan RPM. Pass -1 to set fan to maximum. */
+/* Set the target fan RPM. Pass -1 to set fan to maximum. */
int pwm_set_fan_target_rpm(int rpm);
-/* Gets the keyboard backlight percentage (0=off, 100=max). */
+/* Enable/disable the keyboard backlight. */
+int pwm_enable_keyboard_backlight(int enable);
+
+/* Get the keyboard backlight percentage (0=off, 100=max). */
int pwm_get_keyboard_backlight(void);
-/* Sets the keyboard backlight percentage (0=off, 100=max). */
+/* Set the keyboard backlight percentage (0=off, 100=max). */
int pwm_set_keyboard_backlight(int percent);
-/* Sets the power LED brightness to the specified percent (0=off, 100=max). */
+/* Set the power LED brightness to the specified percent (0=off, 100=max). */
int pwm_set_power_led(int percent);
#endif /* __CROS_EC_PWM_H */
@@ -10,29 +10,32 @@
int pwm_init(void);
-/* Enables/disables the fan. This should be called by whatever function
+/* Enable/disable the fan. This should be called by whatever function
* enables the power supply to the fan. */
int pwm_enable_fan(int enable);